For documentation, make sure to check [the documentation website](https://progressively.app/).

## Run the example

### Start Progressively

Make sure to have a running instance of Progressively:

```sh
$ git clone https://github.com/progressively-crew/progressively
$ cd progressively
$ docker-compose up -d
```

### SDK Python

```sh
$ https://github.com/progressively-crew/sdk-python
$ cd sdk-python
$ make prepare
$ make start
```

And access to the example http://localhost:3003
